"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from datetime import datetime
from pydantic import Field, StrictStr, field_validator
from typing import Any, Optional
from typing_extensions import Annotated
from smartytalent_client.models.conversation_schema import ConversationSchema
from smartytalent_client.models.conversations_schema import ConversationsSchema
from smartytalent_client.models.create_conversation_request_body import CreateConversationRequestBody
from smartytalent_client.models.update_conversation_request_body import UpdateConversationRequestBody

from smartytalent_client.api_client import ApiClient, RequestSerialized
from smartytalent_client.api_response import ApiResponse
from smartytalent_client.rest import RESTResponseType


class ConversationsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def conversation_options(
        self,
        conversation_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Conversation Options

        Enable CORS by returning correct headers

        :param conversation_id: (required)
        :type conversation_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._conversation_options_serialize(
            conversation_id=conversation_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def conversation_options_with_http_info(
        self,
        conversation_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Conversation Options

        Enable CORS by returning correct headers

        :param conversation_id: (required)
        :type conversation_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._conversation_options_serialize(
            conversation_id=conversation_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def conversation_options_without_preload_content(
        self,
        conversation_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Conversation Options

        Enable CORS by returning correct headers

        :param conversation_id: (required)
        :type conversation_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._conversation_options_serialize(
            conversation_id=conversation_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _conversation_options_serialize(
        self,
        conversation_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if conversation_id is not None:
            _path_params['conversationId'] = conversation_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='OPTIONS',
            resource_path='/v1/conversations/{conversationId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def conversations_options(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Conversations Options

        Enable CORS by returning correct headers

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._conversations_options_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def conversations_options_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Conversations Options

        Enable CORS by returning correct headers

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._conversations_options_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def conversations_options_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Conversations Options

        Enable CORS by returning correct headers

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._conversations_options_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _conversations_options_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='OPTIONS',
            resource_path='/v1/conversations',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def create_conversation(
        self,
        create_conversation_request_body: Annotated[CreateConversationRequestBody, Field(description="A JSON object containing Conversation information")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ConversationSchema:
        """Create Conversation

        Creates a new conversation in your account.  ### Conversation's Attributes  Here is a table that describes the attributes of the conversation object:  | Attribute                  | Type   | Description                                                                 | |----------------------------|--------|-----------------------------------------------------------------------------| | `name`                     | string | The full name of the conversation.                                                | | `status`                   | string | The current status of the conversation (e.g., active, inactive).                  | | `timestamps.created`       | string | The date and time when the conversation was created (ISO 8601 format).            | | `timestamps.modified`      | string | The date and time when the conversation was last modified (ISO 8601 format).      |

        :param create_conversation_request_body: A JSON object containing Conversation information (required)
        :type create_conversation_request_body: CreateConversationRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_conversation_serialize(
            create_conversation_request_body=create_conversation_request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ConversationSchema",
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_conversation_with_http_info(
        self,
        create_conversation_request_body: Annotated[CreateConversationRequestBody, Field(description="A JSON object containing Conversation information")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ConversationSchema]:
        """Create Conversation

        Creates a new conversation in your account.  ### Conversation's Attributes  Here is a table that describes the attributes of the conversation object:  | Attribute                  | Type   | Description                                                                 | |----------------------------|--------|-----------------------------------------------------------------------------| | `name`                     | string | The full name of the conversation.                                                | | `status`                   | string | The current status of the conversation (e.g., active, inactive).                  | | `timestamps.created`       | string | The date and time when the conversation was created (ISO 8601 format).            | | `timestamps.modified`      | string | The date and time when the conversation was last modified (ISO 8601 format).      |

        :param create_conversation_request_body: A JSON object containing Conversation information (required)
        :type create_conversation_request_body: CreateConversationRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_conversation_serialize(
            create_conversation_request_body=create_conversation_request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ConversationSchema",
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_conversation_without_preload_content(
        self,
        create_conversation_request_body: Annotated[CreateConversationRequestBody, Field(description="A JSON object containing Conversation information")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Conversation

        Creates a new conversation in your account.  ### Conversation's Attributes  Here is a table that describes the attributes of the conversation object:  | Attribute                  | Type   | Description                                                                 | |----------------------------|--------|-----------------------------------------------------------------------------| | `name`                     | string | The full name of the conversation.                                                | | `status`                   | string | The current status of the conversation (e.g., active, inactive).                  | | `timestamps.created`       | string | The date and time when the conversation was created (ISO 8601 format).            | | `timestamps.modified`      | string | The date and time when the conversation was last modified (ISO 8601 format).      |

        :param create_conversation_request_body: A JSON object containing Conversation information (required)
        :type create_conversation_request_body: CreateConversationRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_conversation_serialize(
            create_conversation_request_body=create_conversation_request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ConversationSchema",
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_conversation_serialize(
        self,
        create_conversation_request_body,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if create_conversation_request_body is not None:
            _body_params = create_conversation_request_body


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth', 
            'OAuth2Auth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v1/conversations',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_conversation(
        self,
        conversation_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete Conversation

        This endpoint allows you to delete a specific conversation from your account. Once deleted, the conversation's information will be permanently removed and cannot be recovered.

        :param conversation_id: (required)
        :type conversation_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_conversation_serialize(
            conversation_id=conversation_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_conversation_with_http_info(
        self,
        conversation_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete Conversation

        This endpoint allows you to delete a specific conversation from your account. Once deleted, the conversation's information will be permanently removed and cannot be recovered.

        :param conversation_id: (required)
        :type conversation_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_conversation_serialize(
            conversation_id=conversation_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_conversation_without_preload_content(
        self,
        conversation_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete Conversation

        This endpoint allows you to delete a specific conversation from your account. Once deleted, the conversation's information will be permanently removed and cannot be recovered.

        :param conversation_id: (required)
        :type conversation_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_conversation_serialize(
            conversation_id=conversation_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_conversation_serialize(
        self,
        conversation_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if conversation_id is not None:
            _path_params['conversationId'] = conversation_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth', 
            'OAuth2Auth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/v1/conversations/{conversationId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def list_conversations(
        self,
        filter_status: Annotated[Optional[StrictStr], Field(description="Returns conversations with the current status (active, archived). If not provided, the default value will be set to 'active'.")] = None,
        filter_created_from: Annotated[Optional[datetime], Field(description="Filters results to include only those created from the specified date and time. The value must be in ISO 8601 format.")] = None,
        filter_created_to: Annotated[Optional[datetime], Field(description="Filters results to include only those created up to the specified date and time. The value must be in ISO 8601 format.")] = None,
        filter_modified_from: Annotated[Optional[datetime], Field(description="Filters results to include only those modified from the specified date and time. The value must be in ISO 8601 format.")] = None,
        filter_modified_to: Annotated[Optional[datetime], Field(description="Filters results to include only those modified up to the specified date and time. The value must be in ISO 8601 format.")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(le=100, strict=True, ge=1)]], Field(description="Specifies the number of items to retrieve per page. The maximum value is 100.")] = None,
        page_number: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Specifies the page number to retrieve. Used for traditional pagination.")] = None,
        page_after: Annotated[Optional[Any], Field(description="Returns the data encoded in Base64 format, used for cursor-based pagination")] = None,
        page_before: Annotated[Optional[StrictStr], Field(description="Returns the data encoded in Base64 format, used for cursor-based pagination")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ConversationsSchema:
        """List Conversations

        Returns a collection of your account conversations  ## Overview   Returns a collection of your account conversations, sorted by the time they were inserted into the system in ascending order.   ### Conversations Endpoints Pagination  The conversations endpoints support two versions of pagination: traditional and cursor-based. Note that the parameters for these pagination methods cannot coexist; using them together will result in a bad request error.  :::tip Pagination tip  Ensure that when using traditional pagination, you use `pageNumber`, and when using cursor-based pagination, you use either `pageAfter` or `pageBefore`, but not both together.  :::    #### More information For more information, see the [pagination documentation](/docs/pagination).

        :param filter_status: Returns conversations with the current status (active, archived). If not provided, the default value will be set to 'active'.
        :type filter_status: str
        :param filter_created_from: Filters results to include only those created from the specified date and time. The value must be in ISO 8601 format.
        :type filter_created_from: datetime
        :param filter_created_to: Filters results to include only those created up to the specified date and time. The value must be in ISO 8601 format.
        :type filter_created_to: datetime
        :param filter_modified_from: Filters results to include only those modified from the specified date and time. The value must be in ISO 8601 format.
        :type filter_modified_from: datetime
        :param filter_modified_to: Filters results to include only those modified up to the specified date and time. The value must be in ISO 8601 format.
        :type filter_modified_to: datetime
        :param page_size: Specifies the number of items to retrieve per page. The maximum value is 100.
        :type page_size: int
        :param page_number: Specifies the page number to retrieve. Used for traditional pagination.
        :type page_number: int
        :param page_after: Returns the data encoded in Base64 format, used for cursor-based pagination
        :type page_after: object
        :param page_before: Returns the data encoded in Base64 format, used for cursor-based pagination
        :type page_before: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_conversations_serialize(
            filter_status=filter_status,
            filter_created_from=filter_created_from,
            filter_created_to=filter_created_to,
            filter_modified_from=filter_modified_from,
            filter_modified_to=filter_modified_to,
            page_size=page_size,
            page_number=page_number,
            page_after=page_after,
            page_before=page_before,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ConversationsSchema",
            '400': "ErrorSchema",
            '401': "ErrorSchema",
            '404': "ErrorSchema",
            '500': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_conversations_with_http_info(
        self,
        filter_status: Annotated[Optional[StrictStr], Field(description="Returns conversations with the current status (active, archived). If not provided, the default value will be set to 'active'.")] = None,
        filter_created_from: Annotated[Optional[datetime], Field(description="Filters results to include only those created from the specified date and time. The value must be in ISO 8601 format.")] = None,
        filter_created_to: Annotated[Optional[datetime], Field(description="Filters results to include only those created up to the specified date and time. The value must be in ISO 8601 format.")] = None,
        filter_modified_from: Annotated[Optional[datetime], Field(description="Filters results to include only those modified from the specified date and time. The value must be in ISO 8601 format.")] = None,
        filter_modified_to: Annotated[Optional[datetime], Field(description="Filters results to include only those modified up to the specified date and time. The value must be in ISO 8601 format.")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(le=100, strict=True, ge=1)]], Field(description="Specifies the number of items to retrieve per page. The maximum value is 100.")] = None,
        page_number: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Specifies the page number to retrieve. Used for traditional pagination.")] = None,
        page_after: Annotated[Optional[Any], Field(description="Returns the data encoded in Base64 format, used for cursor-based pagination")] = None,
        page_before: Annotated[Optional[StrictStr], Field(description="Returns the data encoded in Base64 format, used for cursor-based pagination")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ConversationsSchema]:
        """List Conversations

        Returns a collection of your account conversations  ## Overview   Returns a collection of your account conversations, sorted by the time they were inserted into the system in ascending order.   ### Conversations Endpoints Pagination  The conversations endpoints support two versions of pagination: traditional and cursor-based. Note that the parameters for these pagination methods cannot coexist; using them together will result in a bad request error.  :::tip Pagination tip  Ensure that when using traditional pagination, you use `pageNumber`, and when using cursor-based pagination, you use either `pageAfter` or `pageBefore`, but not both together.  :::    #### More information For more information, see the [pagination documentation](/docs/pagination).

        :param filter_status: Returns conversations with the current status (active, archived). If not provided, the default value will be set to 'active'.
        :type filter_status: str
        :param filter_created_from: Filters results to include only those created from the specified date and time. The value must be in ISO 8601 format.
        :type filter_created_from: datetime
        :param filter_created_to: Filters results to include only those created up to the specified date and time. The value must be in ISO 8601 format.
        :type filter_created_to: datetime
        :param filter_modified_from: Filters results to include only those modified from the specified date and time. The value must be in ISO 8601 format.
        :type filter_modified_from: datetime
        :param filter_modified_to: Filters results to include only those modified up to the specified date and time. The value must be in ISO 8601 format.
        :type filter_modified_to: datetime
        :param page_size: Specifies the number of items to retrieve per page. The maximum value is 100.
        :type page_size: int
        :param page_number: Specifies the page number to retrieve. Used for traditional pagination.
        :type page_number: int
        :param page_after: Returns the data encoded in Base64 format, used for cursor-based pagination
        :type page_after: object
        :param page_before: Returns the data encoded in Base64 format, used for cursor-based pagination
        :type page_before: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_conversations_serialize(
            filter_status=filter_status,
            filter_created_from=filter_created_from,
            filter_created_to=filter_created_to,
            filter_modified_from=filter_modified_from,
            filter_modified_to=filter_modified_to,
            page_size=page_size,
            page_number=page_number,
            page_after=page_after,
            page_before=page_before,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ConversationsSchema",
            '400': "ErrorSchema",
            '401': "ErrorSchema",
            '404': "ErrorSchema",
            '500': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_conversations_without_preload_content(
        self,
        filter_status: Annotated[Optional[StrictStr], Field(description="Returns conversations with the current status (active, archived). If not provided, the default value will be set to 'active'.")] = None,
        filter_created_from: Annotated[Optional[datetime], Field(description="Filters results to include only those created from the specified date and time. The value must be in ISO 8601 format.")] = None,
        filter_created_to: Annotated[Optional[datetime], Field(description="Filters results to include only those created up to the specified date and time. The value must be in ISO 8601 format.")] = None,
        filter_modified_from: Annotated[Optional[datetime], Field(description="Filters results to include only those modified from the specified date and time. The value must be in ISO 8601 format.")] = None,
        filter_modified_to: Annotated[Optional[datetime], Field(description="Filters results to include only those modified up to the specified date and time. The value must be in ISO 8601 format.")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(le=100, strict=True, ge=1)]], Field(description="Specifies the number of items to retrieve per page. The maximum value is 100.")] = None,
        page_number: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Specifies the page number to retrieve. Used for traditional pagination.")] = None,
        page_after: Annotated[Optional[Any], Field(description="Returns the data encoded in Base64 format, used for cursor-based pagination")] = None,
        page_before: Annotated[Optional[StrictStr], Field(description="Returns the data encoded in Base64 format, used for cursor-based pagination")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Conversations

        Returns a collection of your account conversations  ## Overview   Returns a collection of your account conversations, sorted by the time they were inserted into the system in ascending order.   ### Conversations Endpoints Pagination  The conversations endpoints support two versions of pagination: traditional and cursor-based. Note that the parameters for these pagination methods cannot coexist; using them together will result in a bad request error.  :::tip Pagination tip  Ensure that when using traditional pagination, you use `pageNumber`, and when using cursor-based pagination, you use either `pageAfter` or `pageBefore`, but not both together.  :::    #### More information For more information, see the [pagination documentation](/docs/pagination).

        :param filter_status: Returns conversations with the current status (active, archived). If not provided, the default value will be set to 'active'.
        :type filter_status: str
        :param filter_created_from: Filters results to include only those created from the specified date and time. The value must be in ISO 8601 format.
        :type filter_created_from: datetime
        :param filter_created_to: Filters results to include only those created up to the specified date and time. The value must be in ISO 8601 format.
        :type filter_created_to: datetime
        :param filter_modified_from: Filters results to include only those modified from the specified date and time. The value must be in ISO 8601 format.
        :type filter_modified_from: datetime
        :param filter_modified_to: Filters results to include only those modified up to the specified date and time. The value must be in ISO 8601 format.
        :type filter_modified_to: datetime
        :param page_size: Specifies the number of items to retrieve per page. The maximum value is 100.
        :type page_size: int
        :param page_number: Specifies the page number to retrieve. Used for traditional pagination.
        :type page_number: int
        :param page_after: Returns the data encoded in Base64 format, used for cursor-based pagination
        :type page_after: object
        :param page_before: Returns the data encoded in Base64 format, used for cursor-based pagination
        :type page_before: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_conversations_serialize(
            filter_status=filter_status,
            filter_created_from=filter_created_from,
            filter_created_to=filter_created_to,
            filter_modified_from=filter_modified_from,
            filter_modified_to=filter_modified_to,
            page_size=page_size,
            page_number=page_number,
            page_after=page_after,
            page_before=page_before,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ConversationsSchema",
            '400': "ErrorSchema",
            '401': "ErrorSchema",
            '404': "ErrorSchema",
            '500': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_conversations_serialize(
        self,
        filter_status,
        filter_created_from,
        filter_created_to,
        filter_modified_from,
        filter_modified_to,
        page_size,
        page_number,
        page_after,
        page_before,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if filter_status is not None:
            
            _query_params.append(('filterStatus', filter_status))
            
        if filter_created_from is not None:
            if isinstance(filter_created_from, datetime):
                _query_params.append(
                    (
                        'filterCreatedFrom',
                        filter_created_from.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('filterCreatedFrom', filter_created_from))
            
        if filter_created_to is not None:
            if isinstance(filter_created_to, datetime):
                _query_params.append(
                    (
                        'filterCreatedTo',
                        filter_created_to.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('filterCreatedTo', filter_created_to))
            
        if filter_modified_from is not None:
            if isinstance(filter_modified_from, datetime):
                _query_params.append(
                    (
                        'filterModifiedFrom',
                        filter_modified_from.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('filterModifiedFrom', filter_modified_from))
            
        if filter_modified_to is not None:
            if isinstance(filter_modified_to, datetime):
                _query_params.append(
                    (
                        'filterModifiedTo',
                        filter_modified_to.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('filterModifiedTo', filter_modified_to))
            
        if page_size is not None:
            
            _query_params.append(('pageSize', page_size))
            
        if page_number is not None:
            
            _query_params.append(('pageNumber', page_number))
            
        if page_after is not None:
            
            _query_params.append(('pageAfter', page_after))
            
        if page_before is not None:
            
            _query_params.append(('pageBefore', page_before))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth', 
            'OAuth2Auth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/conversations',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def show_conversation(
        self,
        conversation_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ConversationSchema:
        """Show Conversation

        This endpoint retrieves details of a specific conversation from your account. You can view information such as name, and other relevant attributes of the conversation.

        :param conversation_id: (required)
        :type conversation_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._show_conversation_serialize(
            conversation_id=conversation_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ConversationSchema",
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def show_conversation_with_http_info(
        self,
        conversation_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ConversationSchema]:
        """Show Conversation

        This endpoint retrieves details of a specific conversation from your account. You can view information such as name, and other relevant attributes of the conversation.

        :param conversation_id: (required)
        :type conversation_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._show_conversation_serialize(
            conversation_id=conversation_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ConversationSchema",
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def show_conversation_without_preload_content(
        self,
        conversation_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Show Conversation

        This endpoint retrieves details of a specific conversation from your account. You can view information such as name, and other relevant attributes of the conversation.

        :param conversation_id: (required)
        :type conversation_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._show_conversation_serialize(
            conversation_id=conversation_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ConversationSchema",
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _show_conversation_serialize(
        self,
        conversation_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if conversation_id is not None:
            _path_params['conversationId'] = conversation_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth', 
            'OAuth2Auth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/conversations/{conversationId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_conversation(
        self,
        conversation_id: StrictStr,
        update_conversation_request_body: Annotated[UpdateConversationRequestBody, Field(description="A JSON object containing Conversation information")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ConversationSchema:
        """Update Conversation

        This endpoint allows you to update details of a specific conversation in your account. You can modify information such as name, and other relevant attributes of the conversation. Only the fields provided in the request will be updated.

        :param conversation_id: (required)
        :type conversation_id: str
        :param update_conversation_request_body: A JSON object containing Conversation information (required)
        :type update_conversation_request_body: UpdateConversationRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_conversation_serialize(
            conversation_id=conversation_id,
            update_conversation_request_body=update_conversation_request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ConversationSchema",
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_conversation_with_http_info(
        self,
        conversation_id: StrictStr,
        update_conversation_request_body: Annotated[UpdateConversationRequestBody, Field(description="A JSON object containing Conversation information")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ConversationSchema]:
        """Update Conversation

        This endpoint allows you to update details of a specific conversation in your account. You can modify information such as name, and other relevant attributes of the conversation. Only the fields provided in the request will be updated.

        :param conversation_id: (required)
        :type conversation_id: str
        :param update_conversation_request_body: A JSON object containing Conversation information (required)
        :type update_conversation_request_body: UpdateConversationRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_conversation_serialize(
            conversation_id=conversation_id,
            update_conversation_request_body=update_conversation_request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ConversationSchema",
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_conversation_without_preload_content(
        self,
        conversation_id: StrictStr,
        update_conversation_request_body: Annotated[UpdateConversationRequestBody, Field(description="A JSON object containing Conversation information")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update Conversation

        This endpoint allows you to update details of a specific conversation in your account. You can modify information such as name, and other relevant attributes of the conversation. Only the fields provided in the request will be updated.

        :param conversation_id: (required)
        :type conversation_id: str
        :param update_conversation_request_body: A JSON object containing Conversation information (required)
        :type update_conversation_request_body: UpdateConversationRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_conversation_serialize(
            conversation_id=conversation_id,
            update_conversation_request_body=update_conversation_request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ConversationSchema",
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_conversation_serialize(
        self,
        conversation_id,
        update_conversation_request_body,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if conversation_id is not None:
            _path_params['conversationId'] = conversation_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if update_conversation_request_body is not None:
            _body_params = update_conversation_request_body


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth', 
            'OAuth2Auth'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/v1/conversations/{conversationId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.operations_api import OperationsApi


class TestOperationsApi(unittest.TestCase):
    """OperationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OperationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_operation(self) -> None:
        """Test case for create_operation

        Create Operation
        """
        pass

    def test_delete_operation(self) -> None:
        """Test case for delete_operation

        Delete Operation
        """
        pass

    def test_list_operations(self) -> None:
        """Test case for list_operations

        List Operations
        """
        pass

    def test_operation_options(self) -> None:
        """Test case for operation_options

        Operation Options
        """
        pass

    def test_operations_options(self) -> None:
        """Test case for operations_options

        Operations Options
        """
        pass

    def test_show_operation(self) -> None:
        """Test case for show_operation

        Show Operation
        """
        pass

    def test_update_operation(self) -> None:
        """Test case for update_operation

        Update Operation
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from smartytalent_client.models.resource_timestamps_schema import ResourceTimestampsSchema
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class ReportAttributesSchema(BaseModel):
    """
    ReportAttributesSchema
    """ # noqa: E501
    resource_id: StrictStr = Field(description="Identifier of the resource this report is associated with (job ID or tenant ID)", alias="resourceId")
    resource_type: StrictStr = Field(description="Type of the resource (tenants or jobs)", alias="resourceType")
    period: Optional[StrictStr] = Field(default=None, description="Report period frequency")
    report_content: Optional[StrictStr] = Field(default=None, description="Merged analytics and AI analysis content", alias="reportContent")
    settings: Optional[StrictStr] = Field(default=None, description="Report configuration including email recipients and period preferences")
    short_code: Optional[StrictStr] = Field(default=None, description="Optional short identifier for the report", alias="shortCode")
    source: Optional[StrictStr] = Field(default=None, description="Source of the report creation (e.g. scheduled, manual)")
    status: Optional[StrictStr] = Field(default=None, description="Current status of the report")
    ttl: Optional[StrictStr] = Field(default=None, description="Time-to-live value for automatic report expiration")
    timestamps: Optional[ResourceTimestampsSchema] = None
    __properties: ClassVar[List[str]] = ["resourceId", "resourceType", "period", "reportContent", "settings", "shortCode", "source", "status", "ttl", "timestamps"]

    @field_validator('resource_type')
    def resource_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['tenants', 'jobs']):
            raise ValueError("must be one of enum values ('tenants', 'jobs')")
        return value

    @field_validator('period')
    def period_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['DAILY', 'WEEKLY', 'MONTHLY', 'QUARTERLY', 'YEARLY']):
            raise ValueError("must be one of enum values ('DAILY', 'WEEKLY', 'MONTHLY', 'QUARTERLY', 'YEARLY')")
        return value

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['active', 'inactive', 'pending', 'archived', 'failed']):
            raise ValueError("must be one of enum values ('active', 'inactive', 'pending', 'archived', 'failed')")
        return value

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReportAttributesSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of timestamps
        if self.timestamps:
            _dict['timestamps'] = self.timestamps.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReportAttributesSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "resourceId": obj.get("resourceId"),
            "resourceType": obj.get("resourceType"),
            "period": obj.get("period"),
            "reportContent": obj.get("reportContent"),
            "settings": obj.get("settings"),
            "shortCode": obj.get("shortCode"),
            "source": obj.get("source"),
            "status": obj.get("status"),
            "ttl": obj.get("ttl"),
            "timestamps": ResourceTimestampsSchema.from_dict(obj["timestamps"]) if obj.get("timestamps") is not None else None
        })
        return _obj





# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.job_attributes_settings_conversation_schema import JobAttributesSettingsConversationSchema

class TestJobAttributesSettingsConversationSchema(unittest.TestCase):
    """JobAttributesSettingsConversationSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JobAttributesSettingsConversationSchema:
        """Test JobAttributesSettingsConversationSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JobAttributesSettingsConversationSchema`
        """
        model = JobAttributesSettingsConversationSchema()
        if include_optional:
            return JobAttributesSettingsConversationSchema(
                email = smartytalent_client.models.job_attributes_settings_conversation_email_schema.JobAttributesSettingsConversationEmailSchema(
                    contact = smartytalent_client.models.job_attributes_settings_conversation_email_contact_schema.JobAttributesSettingsConversationEmailContactSchema(
                        cc = [
                            ''
                            ], 
                        bcc = [
                            ''
                            ], ), 
                    delays = smartytalent_client.models.job_attributes_settings_conversation_email_delays_schema.JobAttributesSettingsConversationEmailDelaysSchema(
                        initial = '', ), 
                    external_sender = True, 
                    is_sendable = True, ),
                candidate_interview = smartytalent_client.models.job_attributes_settings_conversation_candidate_interview_schema.JobAttributesSettingsConversationCandidateInterviewSchema(
                    enabled = True, 
                    questions = True, ),
                persona_interview = smartytalent_client.models.job_attributes_settings_conversation_persona_interview_schema.JobAttributesSettingsConversationPersonaInterviewSchema(
                    enabled = True, ),
                tone = ''
            )
        else:
            return JobAttributesSettingsConversationSchema(
        )
        """

    def testJobAttributesSettingsConversationSchema(self):
        """Test JobAttributesSettingsConversationSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.create_ad_request_body import CreateAdRequestBody

class TestCreateAdRequestBody(unittest.TestCase):
    """CreateAdRequestBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateAdRequestBody:
        """Test CreateAdRequestBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateAdRequestBody`
        """
        model = CreateAdRequestBody()
        if include_optional:
            return CreateAdRequestBody(
                data = smartytalent_client.models.create_ad_request_body_data.CreateAdRequestBodyData(
                    type = 'ads', 
                    attributes = smartytalent_client.models.ad_attributes_schema.AdAttributesSchema(
                        job_id = '', 
                        status = '', 
                        platforms = smartytalent_client.models.platforms.platforms(), 
                        images = [
                            smartytalent_client.models.ad_attributes_schema_images_inner.AdAttributesSchema_images_inner(
                                platform = '', 
                                s3_key = '', 
                                size = '', )
                            ], 
                        settings = smartytalent_client.models.settings.settings(), 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                    relationships = smartytalent_client.models.ad_relationships_schema.AdRelationshipsSchema(
                        job = smartytalent_client.models.ad_relationships_job_schema.AdRelationshipsJobSchema(
                            data = smartytalent_client.models.ad_relationships_job_data_schema.AdRelationshipsJobDataSchema(
                                type = 'jobs', 
                                id = '655cde5c9931802df628f3d2de8ca681-2', ), ), ), )
            )
        else:
            return CreateAdRequestBody(
                data = smartytalent_client.models.create_ad_request_body_data.CreateAdRequestBodyData(
                    type = 'ads', 
                    attributes = smartytalent_client.models.ad_attributes_schema.AdAttributesSchema(
                        job_id = '', 
                        status = '', 
                        platforms = smartytalent_client.models.platforms.platforms(), 
                        images = [
                            smartytalent_client.models.ad_attributes_schema_images_inner.AdAttributesSchema_images_inner(
                                platform = '', 
                                s3_key = '', 
                                size = '', )
                            ], 
                        settings = smartytalent_client.models.settings.settings(), 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                    relationships = smartytalent_client.models.ad_relationships_schema.AdRelationshipsSchema(
                        job = smartytalent_client.models.ad_relationships_job_schema.AdRelationshipsJobSchema(
                            data = smartytalent_client.models.ad_relationships_job_data_schema.AdRelationshipsJobDataSchema(
                                type = 'jobs', 
                                id = '655cde5c9931802df628f3d2de8ca681-2', ), ), ), ),
        )
        """

    def testCreateAdRequestBody(self):
        """Test CreateAdRequestBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from smartytalent_client.models.resource_timestamps_schema import ResourceTimestampsSchema
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class CallAttributesSchema(BaseModel):
    """
    CallAttributesSchema
    """ # noqa: E501
    name: Optional[StrictStr] = Field(default=None, description="Call title, e.g. Inbound call from John")
    direction: Optional[StrictStr] = Field(default=None, description="Call direction")
    call_type: Optional[StrictStr] = Field(default=None, description="Type/purpose of the call", alias="callType")
    duration: Optional[StrictInt] = Field(default=None, description="Call duration in seconds")
    outcome: Optional[StrictStr] = Field(default=None, description="Call outcome")
    caller_number: Optional[StrictStr] = Field(default=None, description="Caller phone number in E.164 format", alias="callerNumber")
    called_number: Optional[StrictStr] = Field(default=None, description="Called phone number in E.164 format", alias="calledNumber")
    call_sid: Optional[StrictStr] = Field(default=None, description="Twilio call SID", alias="callSid")
    transcript: Optional[Dict[str, Any]] = Field(default=None, description="Localized transcript entries keyed by locale (e.g. en-US, pl-PL). Each value is an array of {speaker, speakerType, timestamp, endTimestamp, text}.")
    speaker_stats: Optional[List[Dict[str, Any]]] = Field(default=None, description="Speaker statistics with talk percentages and time segments", alias="speakerStats")
    recording_url: Optional[StrictStr] = Field(default=None, description="URL or S3 path to call recording", alias="recordingUrl")
    has_recording: Optional[StrictBool] = Field(default=None, description="Whether a recording exists for this call", alias="hasRecording")
    has_transcript: Optional[StrictBool] = Field(default=None, description="Whether a transcript exists for this call", alias="hasTranscript")
    attendees: Optional[List[Dict[str, Any]]] = Field(default=None, description="Call attendees with name and role")
    ai_notes: Optional[Dict[str, Any]] = Field(default=None, description="Localized AI-generated notes keyed by locale. Each value contains summary, keyNotes, topicsDiscussed, sentiment.", alias="aiNotes")
    short_code: Optional[StrictStr] = Field(default=None, description="Short code identifier", alias="shortCode")
    status: Optional[StrictStr] = None
    timestamps: Optional[ResourceTimestampsSchema] = None
    __properties: ClassVar[List[str]] = ["name", "direction", "callType", "duration", "outcome", "callerNumber", "calledNumber", "callSid", "transcript", "speakerStats", "recordingUrl", "hasRecording", "hasTranscript", "attendees", "aiNotes", "shortCode", "status", "timestamps"]

    @field_validator('direction')
    def direction_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['inbound', 'outbound', 'ai-bot']):
            raise ValueError("must be one of enum values ('inbound', 'outbound', 'ai-bot')")
        return value

    @field_validator('call_type')
    def call_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['candidate-call', 'bot-setup', 'follow-up', 'screening', 'reference-check']):
            raise ValueError("must be one of enum values ('candidate-call', 'bot-setup', 'follow-up', 'screening', 'reference-check')")
        return value

    @field_validator('outcome')
    def outcome_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['connected', 'missed', 'voicemail', 'no-answer', 'busy']):
            raise ValueError("must be one of enum values ('connected', 'missed', 'voicemail', 'no-answer', 'busy')")
        return value

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['active', 'draft', 'archived', 'failed']):
            raise ValueError("must be one of enum values ('active', 'draft', 'archived', 'failed')")
        return value

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CallAttributesSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of timestamps
        if self.timestamps:
            _dict['timestamps'] = self.timestamps.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CallAttributesSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "direction": obj.get("direction"),
            "callType": obj.get("callType"),
            "duration": obj.get("duration"),
            "outcome": obj.get("outcome"),
            "callerNumber": obj.get("callerNumber"),
            "calledNumber": obj.get("calledNumber"),
            "callSid": obj.get("callSid"),
            "transcript": obj.get("transcript"),
            "speakerStats": obj.get("speakerStats"),
            "recordingUrl": obj.get("recordingUrl"),
            "hasRecording": obj.get("hasRecording"),
            "hasTranscript": obj.get("hasTranscript"),
            "attendees": obj.get("attendees"),
            "aiNotes": obj.get("aiNotes"),
            "shortCode": obj.get("shortCode"),
            "status": obj.get("status"),
            "timestamps": ResourceTimestampsSchema.from_dict(obj["timestamps"]) if obj.get("timestamps") is not None else None
        })
        return _obj





# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.notifications_api import NotificationsApi


class TestNotificationsApi(unittest.TestCase):
    """NotificationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = NotificationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_notification(self) -> None:
        """Test case for create_notification

        Create Notification
        """
        pass

    def test_delete_notification(self) -> None:
        """Test case for delete_notification

        Delete Notification
        """
        pass

    def test_get_notification(self) -> None:
        """Test case for get_notification

        Get Notification
        """
        pass

    def test_list_notifications(self) -> None:
        """Test case for list_notifications

        List Notifications
        """
        pass

    def test_notification_options(self) -> None:
        """Test case for notification_options

        Notification Options
        """
        pass

    def test_notifications_options(self) -> None:
        """Test case for notifications_options

        Notifications Options
        """
        pass

    def test_update_notification(self) -> None:
        """Test case for update_notification

        Update Notification
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.resources_meta_schema import ResourcesMetaSchema

class TestResourcesMetaSchema(unittest.TestCase):
    """ResourcesMetaSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResourcesMetaSchema:
        """Test ResourcesMetaSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResourcesMetaSchema`
        """
        model = ResourcesMetaSchema()
        if include_optional:
            return ResourcesMetaSchema(
                page = smartytalent_client.models.resources_meta_page_schema.ResourcesMetaPageSchema(
                    cursor = 'MjhkNDljZTc0MzMxNGExOTgzMThmYzlmMWZhZDE0N2YtMQ==', 
                    size = 2, 
                    number = 2, 
                    total_items = 10, 
                    total_pages = 5, ),
                count = smartytalent_client.models.resources_meta_count_schema.ResourcesMetaCountSchema()
            )
        else:
            return ResourcesMetaSchema(
        )
        """

    def testResourcesMetaSchema(self):
        """Test ResourcesMetaSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.tenants_api import TenantsApi


class TestTenantsApi(unittest.TestCase):
    """TenantsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TenantsApi()

    def tearDown(self) -> None:
        pass

    def test_create_tenant(self) -> None:
        """Test case for create_tenant

        Create Tenant
        """
        pass

    def test_create_tenant_upload(self) -> None:
        """Test case for create_tenant_upload

        Create Tenant Upload
        """
        pass

    def test_delete_tenant(self) -> None:
        """Test case for delete_tenant

        Delete Tenant
        """
        pass

    def test_list_tenants(self) -> None:
        """Test case for list_tenants

        List Tenants
        """
        pass

    def test_purchase_tenant_phone_number(self) -> None:
        """Test case for purchase_tenant_phone_number

        Purchase Phone Number
        """
        pass

    def test_release_tenant_phone_number(self) -> None:
        """Test case for release_tenant_phone_number

        Release Phone Number
        """
        pass

    def test_search_tenant_phone_numbers(self) -> None:
        """Test case for search_tenant_phone_numbers

        Search Available Phone Numbers
        """
        pass

    def test_show_tenant(self) -> None:
        """Test case for show_tenant

        Show Tenant
        """
        pass

    def test_tenant_options(self) -> None:
        """Test case for tenant_options

        Tenant Options
        """
        pass

    def test_tenant_phone_numbers_options(self) -> None:
        """Test case for tenant_phone_numbers_options

        Phone Numbers Options
        """
        pass

    def test_tenant_phone_numbers_search_options(self) -> None:
        """Test case for tenant_phone_numbers_search_options

        Phone Numbers Search Options
        """
        pass

    def test_tenant_uploads_options(self) -> None:
        """Test case for tenant_uploads_options

        Tenant Uploads Options
        """
        pass

    def test_tenants_options(self) -> None:
        """Test case for tenants_options

        Tenants Options
        """
        pass

    def test_update_tenant(self) -> None:
        """Test case for update_tenant

        Update Tenant
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.create_notification_request_body import CreateNotificationRequestBody

class TestCreateNotificationRequestBody(unittest.TestCase):
    """CreateNotificationRequestBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateNotificationRequestBody:
        """Test CreateNotificationRequestBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateNotificationRequestBody`
        """
        model = CreateNotificationRequestBody()
        if include_optional:
            return CreateNotificationRequestBody(
                data = smartytalent_client.models.create_notification_request_body_data.CreateNotificationRequestBodyData(
                    type = 'notifications', 
                    attributes = smartytalent_client.models.notification_attributes_schema.NotificationAttributesSchema(
                        title = '', 
                        subtitle = '', 
                        category = 'general', 
                        status = 'unread', 
                        avatar_icon = '', 
                        avatar_text = '', 
                        avatar_image = '', 
                        avatar_color = 'primary', 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    relationships = smartytalent_client.models.notification_relationships_schema.NotificationRelationshipsSchema(
                        users = smartytalent_client.models.notification_relationships_schema_users.NotificationRelationshipsSchema_users(
                            data = [
                                smartytalent_client.models.notification_relationships_schema_users_data_inner.NotificationRelationshipsSchema_users_data_inner(
                                    type = 'users', 
                                    id = '655cde5c9931802df628f3d2de8ca681-1', )
                                ], ), ), )
            )
        else:
            return CreateNotificationRequestBody(
                data = smartytalent_client.models.create_notification_request_body_data.CreateNotificationRequestBodyData(
                    type = 'notifications', 
                    attributes = smartytalent_client.models.notification_attributes_schema.NotificationAttributesSchema(
                        title = '', 
                        subtitle = '', 
                        category = 'general', 
                        status = 'unread', 
                        avatar_icon = '', 
                        avatar_text = '', 
                        avatar_image = '', 
                        avatar_color = 'primary', 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    relationships = smartytalent_client.models.notification_relationships_schema.NotificationRelationshipsSchema(
                        users = smartytalent_client.models.notification_relationships_schema_users.NotificationRelationshipsSchema_users(
                            data = [
                                smartytalent_client.models.notification_relationships_schema_users_data_inner.NotificationRelationshipsSchema_users_data_inner(
                                    type = 'users', 
                                    id = '655cde5c9931802df628f3d2de8ca681-1', )
                                ], ), ), ),
        )
        """

    def testCreateNotificationRequestBody(self):
        """Test CreateNotificationRequestBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from smartytalent_client.models.job_attributes_location_item_schema import JobAttributesLocationItemSchema
from smartytalent_client.models.job_attributes_organization_schema import JobAttributesOrganizationSchema
from smartytalent_client.models.job_attributes_settings_schema import JobAttributesSettingsSchema
from smartytalent_client.models.job_attributes_site_item_schema import JobAttributesSiteItemSchema
from smartytalent_client.models.job_criteria_schema import JobCriteriaSchema
from smartytalent_client.models.resource_timestamps_schema import ResourceTimestampsSchema
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class JobAttributesSchema(BaseModel):
    """
    JobAttributesSchema
    """ # noqa: E501
    title: Dict[str, StrictStr] = Field(description="The job title/position. Language-keyed object where keys are locale codes (e.g. en-US, pl-PL).")
    description: Optional[Dict[str, StrictStr]] = Field(default=None, description="Detailed job description. Language-keyed object.")
    short_code: Optional[StrictStr] = Field(default=None, description="Unique short identifier for the job", alias="shortCode")
    source: Optional[StrictStr] = Field(default=None, description="Source of the job posting (e.g. email, erecruiter)")
    language_code: Optional[StrictStr] = Field(default=None, description="Primary language code for the job posting (e.g. en-US, pl-PL)", alias="languageCode")
    status: Optional[StrictStr] = None
    timestamps: Optional[ResourceTimestampsSchema] = None
    department: Optional[Dict[str, StrictStr]] = Field(default=None, description="Department where the position is located. Language-keyed object.")
    specialization: Optional[Dict[str, StrictStr]] = Field(default=None, description="Job specialization area. Language-keyed object.")
    company_culture: Optional[StrictStr] = Field(default=None, description="Description of the company's culture and values", alias="companyCulture")
    seniority: Optional[StrictStr] = Field(default=None, description="Seniority level for the role (e.g. junior, mid, senior)")
    availability: Optional[Dict[str, JobCriteriaSchema]] = Field(default=None, description="Availability criteria. Language-keyed object containing criteria with name, description, priority, comparisonRule and expected values.")
    responsibilities: Optional[Dict[str, List[StrictStr]]] = Field(default=None, description="List of job responsibilities. Language-keyed object where each language maps to an array of strings.")
    skills_and_expertise: Optional[Dict[str, JobCriteriaSchema]] = Field(default=None, description="Technical skills and domain expertise criteria. Language-keyed object containing criteria with expected skills.", alias="skillsAndExpertise")
    languages_spoken: Optional[Dict[str, JobCriteriaSchema]] = Field(default=None, description="Language proficiency requirements. Language-keyed object containing criteria with expected languages.", alias="languagesSpoken")
    work_preferences: Optional[Dict[str, JobCriteriaSchema]] = Field(default=None, description="Work style and schedule preferences. Language-keyed object containing criteria.", alias="workPreferences")
    location_preferences: Optional[Dict[str, JobCriteriaSchema]] = Field(default=None, description="Geographic location requirements. Language-keyed object containing criteria with expected locations.", alias="locationPreferences")
    industry_experience: Optional[Dict[str, JobCriteriaSchema]] = Field(default=None, description="Industry sector experience requirements. Language-keyed object containing criteria.", alias="industryExperience")
    company_type_experience: Optional[Dict[str, JobCriteriaSchema]] = Field(default=None, description="Company type experience requirements. Language-keyed object containing criteria.", alias="companyTypeExperience")
    job_positions: Optional[Dict[str, JobCriteriaSchema]] = Field(default=None, description="Required previous job positions. Language-keyed object containing criteria.", alias="jobPositions")
    job_tendencies: Optional[Dict[str, JobCriteriaSchema]] = Field(default=None, description="Career pattern and progression requirements. Language-keyed object containing criteria.", alias="jobTendencies")
    keywords: Optional[Dict[str, List[StrictStr]]] = Field(default=None, description="Relevant keywords for the position. Language-keyed object where each language maps to an array of strings.")
    work_authorization: Optional[Dict[str, JobCriteriaSchema]] = Field(default=None, description="Work authorization requirements. Language-keyed object containing criteria.", alias="workAuthorization")
    certifications: Optional[Dict[str, JobCriteriaSchema]] = Field(default=None, description="Professional certifications requirements. Language-keyed object containing criteria.")
    licenses: Optional[Dict[str, JobCriteriaSchema]] = Field(default=None, description="Professional licenses requirements. Language-keyed object containing criteria.")
    personality_and_soft_skills: Optional[Dict[str, JobCriteriaSchema]] = Field(default=None, description="Soft skills and personality trait requirements. Language-keyed object containing criteria.", alias="personalityAndSoftSkills")
    education: Optional[Dict[str, JobCriteriaSchema]] = Field(default=None, description="Education requirements. Language-keyed object containing criteria.")
    experience_and_seniority: Optional[Dict[str, JobCriteriaSchema]] = Field(default=None, description="Experience and seniority level requirements. Language-keyed object containing criteria.", alias="experienceAndSeniority")
    benefits: Optional[Dict[str, List[StrictStr]]] = Field(default=None, description="Job benefits. Language-keyed object where each language maps to an array of strings.")
    salary_expectation: Optional[Dict[str, JobCriteriaSchema]] = Field(default=None, description="Salary and compensation criteria. Language-keyed object containing criteria with expected salary ranges.", alias="salaryExpectation")
    locations: Optional[Dict[str, List[JobAttributesLocationItemSchema]]] = Field(default=None, description="Office locations for the job. Language-keyed object where each language maps to an array of location objects.")
    sites: Optional[Dict[str, List[JobAttributesSiteItemSchema]]] = Field(default=None, description="Work site types for the job. Language-keyed object where each language maps to an array of site objects.")
    organization: Optional[JobAttributesOrganizationSchema] = None
    settings: Optional[JobAttributesSettingsSchema] = None
    __properties: ClassVar[List[str]] = ["title", "description", "shortCode", "source", "languageCode", "status", "timestamps", "department", "specialization", "companyCulture", "seniority", "availability", "responsibilities", "skillsAndExpertise", "languagesSpoken", "workPreferences", "locationPreferences", "industryExperience", "companyTypeExperience", "jobPositions", "jobTendencies", "keywords", "workAuthorization", "certifications", "licenses", "personalityAndSoftSkills", "education", "experienceAndSeniority", "benefits", "salaryExpectation", "locations", "sites", "organization", "settings"]

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['active', 'inactive', 'draft', 'pending', 'archived', 'failed']):
            raise ValueError("must be one of enum values ('active', 'inactive', 'draft', 'pending', 'archived', 'failed')")
        return value

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of JobAttributesSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of timestamps
        if self.timestamps:
            _dict['timestamps'] = self.timestamps.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each value in availability (dict)
        _field_dict = {}
        if self.availability:
            for _key_availability in self.availability:
                if self.availability[_key_availability]:
                    _field_dict[_key_availability] = self.availability[_key_availability].to_dict()
            _dict['availability'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in skills_and_expertise (dict)
        _field_dict = {}
        if self.skills_and_expertise:
            for _key_skills_and_expertise in self.skills_and_expertise:
                if self.skills_and_expertise[_key_skills_and_expertise]:
                    _field_dict[_key_skills_and_expertise] = self.skills_and_expertise[_key_skills_and_expertise].to_dict()
            _dict['skillsAndExpertise'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in languages_spoken (dict)
        _field_dict = {}
        if self.languages_spoken:
            for _key_languages_spoken in self.languages_spoken:
                if self.languages_spoken[_key_languages_spoken]:
                    _field_dict[_key_languages_spoken] = self.languages_spoken[_key_languages_spoken].to_dict()
            _dict['languagesSpoken'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in work_preferences (dict)
        _field_dict = {}
        if self.work_preferences:
            for _key_work_preferences in self.work_preferences:
                if self.work_preferences[_key_work_preferences]:
                    _field_dict[_key_work_preferences] = self.work_preferences[_key_work_preferences].to_dict()
            _dict['workPreferences'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in location_preferences (dict)
        _field_dict = {}
        if self.location_preferences:
            for _key_location_preferences in self.location_preferences:
                if self.location_preferences[_key_location_preferences]:
                    _field_dict[_key_location_preferences] = self.location_preferences[_key_location_preferences].to_dict()
            _dict['locationPreferences'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in industry_experience (dict)
        _field_dict = {}
        if self.industry_experience:
            for _key_industry_experience in self.industry_experience:
                if self.industry_experience[_key_industry_experience]:
                    _field_dict[_key_industry_experience] = self.industry_experience[_key_industry_experience].to_dict()
            _dict['industryExperience'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in company_type_experience (dict)
        _field_dict = {}
        if self.company_type_experience:
            for _key_company_type_experience in self.company_type_experience:
                if self.company_type_experience[_key_company_type_experience]:
                    _field_dict[_key_company_type_experience] = self.company_type_experience[_key_company_type_experience].to_dict()
            _dict['companyTypeExperience'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in job_positions (dict)
        _field_dict = {}
        if self.job_positions:
            for _key_job_positions in self.job_positions:
                if self.job_positions[_key_job_positions]:
                    _field_dict[_key_job_positions] = self.job_positions[_key_job_positions].to_dict()
            _dict['jobPositions'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in job_tendencies (dict)
        _field_dict = {}
        if self.job_tendencies:
            for _key_job_tendencies in self.job_tendencies:
                if self.job_tendencies[_key_job_tendencies]:
                    _field_dict[_key_job_tendencies] = self.job_tendencies[_key_job_tendencies].to_dict()
            _dict['jobTendencies'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in work_authorization (dict)
        _field_dict = {}
        if self.work_authorization:
            for _key_work_authorization in self.work_authorization:
                if self.work_authorization[_key_work_authorization]:
                    _field_dict[_key_work_authorization] = self.work_authorization[_key_work_authorization].to_dict()
            _dict['workAuthorization'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in certifications (dict)
        _field_dict = {}
        if self.certifications:
            for _key_certifications in self.certifications:
                if self.certifications[_key_certifications]:
                    _field_dict[_key_certifications] = self.certifications[_key_certifications].to_dict()
            _dict['certifications'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in licenses (dict)
        _field_dict = {}
        if self.licenses:
            for _key_licenses in self.licenses:
                if self.licenses[_key_licenses]:
                    _field_dict[_key_licenses] = self.licenses[_key_licenses].to_dict()
            _dict['licenses'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in personality_and_soft_skills (dict)
        _field_dict = {}
        if self.personality_and_soft_skills:
            for _key_personality_and_soft_skills in self.personality_and_soft_skills:
                if self.personality_and_soft_skills[_key_personality_and_soft_skills]:
                    _field_dict[_key_personality_and_soft_skills] = self.personality_and_soft_skills[_key_personality_and_soft_skills].to_dict()
            _dict['personalityAndSoftSkills'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in education (dict)
        _field_dict = {}
        if self.education:
            for _key_education in self.education:
                if self.education[_key_education]:
                    _field_dict[_key_education] = self.education[_key_education].to_dict()
            _dict['education'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in experience_and_seniority (dict)
        _field_dict = {}
        if self.experience_and_seniority:
            for _key_experience_and_seniority in self.experience_and_seniority:
                if self.experience_and_seniority[_key_experience_and_seniority]:
                    _field_dict[_key_experience_and_seniority] = self.experience_and_seniority[_key_experience_and_seniority].to_dict()
            _dict['experienceAndSeniority'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in salary_expectation (dict)
        _field_dict = {}
        if self.salary_expectation:
            for _key_salary_expectation in self.salary_expectation:
                if self.salary_expectation[_key_salary_expectation]:
                    _field_dict[_key_salary_expectation] = self.salary_expectation[_key_salary_expectation].to_dict()
            _dict['salaryExpectation'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in locations (dict of array)
        _field_dict_of_array = {}
        if self.locations:
            for _key_locations in self.locations:
                if self.locations[_key_locations] is not None:
                    _field_dict_of_array[_key_locations] = [
                        _item.to_dict() for _item in self.locations[_key_locations]
                    ]
            _dict['locations'] = _field_dict_of_array
        # override the default output from pydantic by calling `to_dict()` of each value in sites (dict of array)
        _field_dict_of_array = {}
        if self.sites:
            for _key_sites in self.sites:
                if self.sites[_key_sites] is not None:
                    _field_dict_of_array[_key_sites] = [
                        _item.to_dict() for _item in self.sites[_key_sites]
                    ]
            _dict['sites'] = _field_dict_of_array
        # override the default output from pydantic by calling `to_dict()` of organization
        if self.organization:
            _dict['organization'] = self.organization.to_dict()
        # override the default output from pydantic by calling `to_dict()` of settings
        if self.settings:
            _dict['settings'] = self.settings.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of JobAttributesSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "title": obj.get("title"),
            "description": obj.get("description"),
            "shortCode": obj.get("shortCode"),
            "source": obj.get("source"),
            "languageCode": obj.get("languageCode"),
            "status": obj.get("status"),
            "timestamps": ResourceTimestampsSchema.from_dict(obj["timestamps"]) if obj.get("timestamps") is not None else None,
            "department": obj.get("department"),
            "specialization": obj.get("specialization"),
            "companyCulture": obj.get("companyCulture"),
            "seniority": obj.get("seniority"),
            "availability": dict(
                (_k, JobCriteriaSchema.from_dict(_v))
                for _k, _v in obj["availability"].items()
            )
            if obj.get("availability") is not None
            else None,
            "responsibilities": obj.get("responsibilities"),
            "skillsAndExpertise": dict(
                (_k, JobCriteriaSchema.from_dict(_v))
                for _k, _v in obj["skillsAndExpertise"].items()
            )
            if obj.get("skillsAndExpertise") is not None
            else None,
            "languagesSpoken": dict(
                (_k, JobCriteriaSchema.from_dict(_v))
                for _k, _v in obj["languagesSpoken"].items()
            )
            if obj.get("languagesSpoken") is not None
            else None,
            "workPreferences": dict(
                (_k, JobCriteriaSchema.from_dict(_v))
                for _k, _v in obj["workPreferences"].items()
            )
            if obj.get("workPreferences") is not None
            else None,
            "locationPreferences": dict(
                (_k, JobCriteriaSchema.from_dict(_v))
                for _k, _v in obj["locationPreferences"].items()
            )
            if obj.get("locationPreferences") is not None
            else None,
            "industryExperience": dict(
                (_k, JobCriteriaSchema.from_dict(_v))
                for _k, _v in obj["industryExperience"].items()
            )
            if obj.get("industryExperience") is not None
            else None,
            "companyTypeExperience": dict(
                (_k, JobCriteriaSchema.from_dict(_v))
                for _k, _v in obj["companyTypeExperience"].items()
            )
            if obj.get("companyTypeExperience") is not None
            else None,
            "jobPositions": dict(
                (_k, JobCriteriaSchema.from_dict(_v))
                for _k, _v in obj["jobPositions"].items()
            )
            if obj.get("jobPositions") is not None
            else None,
            "jobTendencies": dict(
                (_k, JobCriteriaSchema.from_dict(_v))
                for _k, _v in obj["jobTendencies"].items()
            )
            if obj.get("jobTendencies") is not None
            else None,
            "keywords": obj.get("keywords"),
            "workAuthorization": dict(
                (_k, JobCriteriaSchema.from_dict(_v))
                for _k, _v in obj["workAuthorization"].items()
            )
            if obj.get("workAuthorization") is not None
            else None,
            "certifications": dict(
                (_k, JobCriteriaSchema.from_dict(_v))
                for _k, _v in obj["certifications"].items()
            )
            if obj.get("certifications") is not None
            else None,
            "licenses": dict(
                (_k, JobCriteriaSchema.from_dict(_v))
                for _k, _v in obj["licenses"].items()
            )
            if obj.get("licenses") is not None
            else None,
            "personalityAndSoftSkills": dict(
                (_k, JobCriteriaSchema.from_dict(_v))
                for _k, _v in obj["personalityAndSoftSkills"].items()
            )
            if obj.get("personalityAndSoftSkills") is not None
            else None,
            "education": dict(
                (_k, JobCriteriaSchema.from_dict(_v))
                for _k, _v in obj["education"].items()
            )
            if obj.get("education") is not None
            else None,
            "experienceAndSeniority": dict(
                (_k, JobCriteriaSchema.from_dict(_v))
                for _k, _v in obj["experienceAndSeniority"].items()
            )
            if obj.get("experienceAndSeniority") is not None
            else None,
            "benefits": obj.get("benefits"),
            "salaryExpectation": dict(
                (_k, JobCriteriaSchema.from_dict(_v))
                for _k, _v in obj["salaryExpectation"].items()
            )
            if obj.get("salaryExpectation") is not None
            else None,
            "locations": dict(
                (_k,
                        [JobAttributesLocationItemSchema.from_dict(_item) for _item in _v]
                        if _v is not None
                        else None
                )
                for _k, _v in obj.get("locations", {}).items()
            ),
            "sites": dict(
                (_k,
                        [JobAttributesSiteItemSchema.from_dict(_item) for _item in _v]
                        if _v is not None
                        else None
                )
                for _k, _v in obj.get("sites", {}).items()
            ),
            "organization": JobAttributesOrganizationSchema.from_dict(obj["organization"]) if obj.get("organization") is not None else None,
            "settings": JobAttributesSettingsSchema.from_dict(obj["settings"]) if obj.get("settings") is not None else None
        })
        return _obj





# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class NotificationAttributesSchema(BaseModel):
    """
    NotificationAttributesSchema
    """ # noqa: E501
    title: StrictStr = Field(description="The notification title")
    subtitle: Optional[StrictStr] = Field(default=None, description="The notification subtitle")
    category: Optional[StrictStr] = Field(default='general', description="The notification category")
    status: Optional[StrictStr] = Field(default='unread', description="Read/unread status")
    avatar_icon: Optional[StrictStr] = Field(default=None, description="Tabler icon name for the notification avatar", alias="avatarIcon")
    avatar_text: Optional[StrictStr] = Field(default=None, description="Text to display in the notification avatar", alias="avatarText")
    avatar_image: Optional[StrictStr] = Field(default=None, description="Image URL for the notification avatar", alias="avatarImage")
    avatar_color: Optional[StrictStr] = Field(default='primary', description="Color theme for the notification avatar", alias="avatarColor")
    created: Optional[datetime] = Field(default=None, description="Creation timestamp")
    modified: Optional[datetime] = Field(default=None, description="Last modified timestamp")
    __properties: ClassVar[List[str]] = ["title", "subtitle", "category", "status", "avatarIcon", "avatarText", "avatarImage", "avatarColor", "created", "modified"]

    @field_validator('category')
    def category_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['general', 'task', 'finder', 'candidate', 'file', 'assessment']):
            raise ValueError("must be one of enum values ('general', 'task', 'finder', 'candidate', 'file', 'assessment')")
        return value

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['read', 'unread']):
            raise ValueError("must be one of enum values ('read', 'unread')")
        return value

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NotificationAttributesSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NotificationAttributesSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "title": obj.get("title"),
            "subtitle": obj.get("subtitle"),
            "category": obj.get("category") if obj.get("category") is not None else 'general',
            "status": obj.get("status") if obj.get("status") is not None else 'unread',
            "avatarIcon": obj.get("avatarIcon"),
            "avatarText": obj.get("avatarText"),
            "avatarImage": obj.get("avatarImage"),
            "avatarColor": obj.get("avatarColor") if obj.get("avatarColor") is not None else 'primary',
            "created": obj.get("created"),
            "modified": obj.get("modified")
        })
        return _obj





# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from smartytalent_client.models.resource_timestamps_schema import ResourceTimestampsSchema
from smartytalent_client.models.tenant_attributes_address_schema import TenantAttributesAddressSchema
from smartytalent_client.models.tenant_attributes_settings_schema import TenantAttributesSettingsSchema
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class TenantAttributesSchema(BaseModel):
    """
    TenantAttributesSchema
    """ # noqa: E501
    name: StrictStr
    username: Optional[StrictStr] = None
    email: Annotated[str, Field(min_length=5, strict=True, max_length=255)]
    status: Optional[StrictStr] = None
    short_code: Optional[StrictStr] = Field(default=None, alias="shortCode")
    timestamps: Optional[ResourceTimestampsSchema] = None
    phone: Optional[StrictStr] = None
    address: Optional[TenantAttributesAddressSchema] = None
    settings: Optional[TenantAttributesSettingsSchema] = None
    plan: Annotated[str, Field(min_length=1, strict=True, max_length=255)]
    active_languages: Optional[List[Annotated[str, Field(strict=True)]]] = Field(default=None, alias="activeLanguages")
    trial_expiry_date: Optional[datetime] = Field(default=None, alias="trialExpiryDate")
    timezone: Optional[StrictStr] = None
    logo_url: Optional[StrictStr] = Field(default=None, alias="logoUrl")
    boe_phone: Optional[StrictStr] = Field(default=None, description="Twilio phone number assigned to the Boe AI agent for this tenant", alias="boePhone")
    boe_email: Optional[StrictStr] = Field(default=None, description="Email address assigned to the Boe AI agent for this tenant", alias="boeEmail")
    __properties: ClassVar[List[str]] = ["name", "username", "email", "status", "shortCode", "timestamps", "phone", "address", "settings", "plan", "activeLanguages", "trialExpiryDate", "timezone", "logoUrl", "boePhone", "boeEmail"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TenantAttributesSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of timestamps
        if self.timestamps:
            _dict['timestamps'] = self.timestamps.to_dict()
        # override the default output from pydantic by calling `to_dict()` of address
        if self.address:
            _dict['address'] = self.address.to_dict()
        # override the default output from pydantic by calling `to_dict()` of settings
        if self.settings:
            _dict['settings'] = self.settings.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TenantAttributesSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "username": obj.get("username"),
            "email": obj.get("email"),
            "status": obj.get("status"),
            "shortCode": obj.get("shortCode"),
            "timestamps": ResourceTimestampsSchema.from_dict(obj["timestamps"]) if obj.get("timestamps") is not None else None,
            "phone": obj.get("phone"),
            "address": TenantAttributesAddressSchema.from_dict(obj["address"]) if obj.get("address") is not None else None,
            "settings": TenantAttributesSettingsSchema.from_dict(obj["settings"]) if obj.get("settings") is not None else None,
            "plan": obj.get("plan"),
            "activeLanguages": obj.get("activeLanguages"),
            "trialExpiryDate": obj.get("trialExpiryDate"),
            "timezone": obj.get("timezone"),
            "logoUrl": obj.get("logoUrl"),
            "boePhone": obj.get("boePhone"),
            "boeEmail": obj.get("boeEmail")
        })
        return _obj





# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.candidate_attributes_schema import CandidateAttributesSchema

class TestCandidateAttributesSchema(unittest.TestCase):
    """CandidateAttributesSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CandidateAttributesSchema:
        """Test CandidateAttributesSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CandidateAttributesSchema`
        """
        model = CandidateAttributesSchema()
        if include_optional:
            return CandidateAttributesSchema(
                name = '',
                email = '',
                secondary_email = '',
                work_email = '',
                phone = '',
                work_phone = '',
                status = 'active',
                stage = 'sourced',
                age = '',
                gender = '',
                source = '',
                short_code = '',
                language_code = '',
                recommendation_status_code = 56,
                overall_match_rating = 56,
                prev_overall_match_rating = 56,
                ttl = '',
                timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                alumni = smartytalent_client.models.talent_alumni_schema.TalentAlumniSchema(
                    is_former_employee = True, 
                    previous_tenure_months = 1.337, 
                    wants_to_return = True, ),
                referral = smartytalent_client.models.talent_referral_schema.TalentReferralSchema(
                    is_referred = True, 
                    referral_code = '', 
                    referrer = smartytalent_client.models.talent_referral_schema_referrer.TalentReferralSchema_referrer(
                        email = '', 
                        full_name = '', ), ),
                job_position_title = {
                    'key' : ''
                    },
                rejection_ticket = {
                    'key' : ''
                    },
                recommendation_status = {
                    'key' : None
                    },
                overall_assessment = {
                    'key' : None
                    },
                next_steps = {
                    'key' : None
                    },
                insights_and_analysis = {
                    'key' : None
                    },
                keywords = {
                    'key' : None
                    },
                availability = {
                    'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        expected = [
                            None
                            ], 
                        received = [
                            None
                            ], 
                        weight = '', 
                        rating = 1.337, 
                        prev_rating = 1.337, 
                        data_available = True, 
                        comparison_confidence = '', 
                        comparison_reasoning = '', 
                        is_comparison_assumed = True, )
                    },
                certifications = {
                    'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        expected = [
                            None
                            ], 
                        received = [
                            None
                            ], 
                        weight = '', 
                        rating = 1.337, 
                        prev_rating = 1.337, 
                        data_available = True, 
                        comparison_confidence = '', 
                        comparison_reasoning = '', 
                        is_comparison_assumed = True, )
                    },
                company_type_experience = {
                    'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        expected = [
                            None
                            ], 
                        received = [
                            None
                            ], 
                        weight = '', 
                        rating = 1.337, 
                        prev_rating = 1.337, 
                        data_available = True, 
                        comparison_confidence = '', 
                        comparison_reasoning = '', 
                        is_comparison_assumed = True, )
                    },
                education = {
                    'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        expected = [
                            None
                            ], 
                        received = [
                            None
                            ], 
                        weight = '', 
                        rating = 1.337, 
                        prev_rating = 1.337, 
                        data_available = True, 
                        comparison_confidence = '', 
                        comparison_reasoning = '', 
                        is_comparison_assumed = True, )
                    },
                experience_and_seniority = {
                    'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        expected = [
                            None
                            ], 
                        received = [
                            None
                            ], 
                        weight = '', 
                        rating = 1.337, 
                        prev_rating = 1.337, 
                        data_available = True, 
                        comparison_confidence = '', 
                        comparison_reasoning = '', 
                        is_comparison_assumed = True, )
                    },
                industry_experience = {
                    'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        expected = [
                            None
                            ], 
                        received = [
                            None
                            ], 
                        weight = '', 
                        rating = 1.337, 
                        prev_rating = 1.337, 
                        data_available = True, 
                        comparison_confidence = '', 
                        comparison_reasoning = '', 
                        is_comparison_assumed = True, )
                    },
                job_positions = {
                    'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        expected = [
                            None
                            ], 
                        received = [
                            None
                            ], 
                        weight = '', 
                        rating = 1.337, 
                        prev_rating = 1.337, 
                        data_available = True, 
                        comparison_confidence = '', 
                        comparison_reasoning = '', 
                        is_comparison_assumed = True, )
                    },
                job_tendencies = {
                    'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        expected = [
                            None
                            ], 
                        received = [
                            None
                            ], 
                        weight = '', 
                        rating = 1.337, 
                        prev_rating = 1.337, 
                        data_available = True, 
                        comparison_confidence = '', 
                        comparison_reasoning = '', 
                        is_comparison_assumed = True, )
                    },
                languages_spoken = {
                    'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        expected = [
                            None
                            ], 
                        received = [
                            None
                            ], 
                        weight = '', 
                        rating = 1.337, 
                        prev_rating = 1.337, 
                        data_available = True, 
                        comparison_confidence = '', 
                        comparison_reasoning = '', 
                        is_comparison_assumed = True, )
                    },
                licenses = {
                    'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        expected = [
                            None
                            ], 
                        received = [
                            None
                            ], 
                        weight = '', 
                        rating = 1.337, 
                        prev_rating = 1.337, 
                        data_available = True, 
                        comparison_confidence = '', 
                        comparison_reasoning = '', 
                        is_comparison_assumed = True, )
                    },
                location_preferences = {
                    'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        expected = [
                            None
                            ], 
                        received = [
                            None
                            ], 
                        weight = '', 
                        rating = 1.337, 
                        prev_rating = 1.337, 
                        data_available = True, 
                        comparison_confidence = '', 
                        comparison_reasoning = '', 
                        is_comparison_assumed = True, )
                    },
                personality_and_soft_skills = {
                    'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        expected = [
                            None
                            ], 
                        received = [
                            None
                            ], 
                        weight = '', 
                        rating = 1.337, 
                        prev_rating = 1.337, 
                        data_available = True, 
                        comparison_confidence = '', 
                        comparison_reasoning = '', 
                        is_comparison_assumed = True, )
                    },
                salary_expectation = {
                    'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        expected = [
                            None
                            ], 
                        received = [
                            None
                            ], 
                        weight = '', 
                        rating = 1.337, 
                        prev_rating = 1.337, 
                        data_available = True, 
                        comparison_confidence = '', 
                        comparison_reasoning = '', 
                        is_comparison_assumed = True, )
                    },
                skills_and_expertise = {
                    'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        expected = [
                            None
                            ], 
                        received = [
                            None
                            ], 
                        weight = '', 
                        rating = 1.337, 
                        prev_rating = 1.337, 
                        data_available = True, 
                        comparison_confidence = '', 
                        comparison_reasoning = '', 
                        is_comparison_assumed = True, )
                    },
                work_authorization = {
                    'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        expected = [
                            None
                            ], 
                        received = [
                            None
                            ], 
                        weight = '', 
                        rating = 1.337, 
                        prev_rating = 1.337, 
                        data_available = True, 
                        comparison_confidence = '', 
                        comparison_reasoning = '', 
                        is_comparison_assumed = True, )
                    },
                work_preferences = {
                    'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        expected = [
                            None
                            ], 
                        received = [
                            None
                            ], 
                        weight = '', 
                        rating = 1.337, 
                        prev_rating = 1.337, 
                        data_available = True, 
                        comparison_confidence = '', 
                        comparison_reasoning = '', 
                        is_comparison_assumed = True, )
                    }
            )
        else:
            return CandidateAttributesSchema(
                name = '',
                email = '',
        )
        """

    def testCandidateAttributesSchema(self):
        """Test CandidateAttributesSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
